summaryrefslogtreecommitdiff
path: root/server
diff options
context:
space:
mode:
authorTimotej Lazar <timotej.lazar@araneo.org>2015-09-29 11:38:09 +0200
committerTimotej Lazar <timotej.lazar@araneo.org>2015-09-29 11:38:09 +0200
commit11c84622f9a3943824c0133c2ab96aeb7ba46038 (patch)
treea1f9d01382f32c5a56ce69bf301217e6a215c95e /server
parente58c8bd7ea894e28a23a68b664772314720cd879 (diff)
Add HintPopup and set hint_type on Hint* classes
Diffstat (limited to 'server')
-rw-r--r--server/hints.py18
1 files changed, 15 insertions, 3 deletions
diff --git a/server/hints.py b/server/hints.py
index 872827f..4c97510 100644
--- a/server/hints.py
+++ b/server/hints.py
@@ -3,16 +3,18 @@
# Hint.instantiate takes a hint object (dictionary) to be sent to the client
# and sets additional fields based on previously sent hints.
-# Simple hint: don't do anything.
+# Simple hint: don't do anything on instantiation.
class Hint(object):
+ hint_type = 'static'
+
def __init__(self, name):
self.name = name
def instantiate(self, hint, prev_hints):
pass
# Hint sequence: each time this hint is sent, increase the message index until
# the last message is reached, then repeat that.
class HintSequence(Hint):
def __init__(self, name, length):
self.name = name
@@ -25,3 +27,13 @@ class HintSequence(Hint):
index = max(index, prev_hint['indices'][0]+1)
index = min(index, self.length-1)
hint['indices'] = [index]
+
+# Popup hints: don't do anything on instantiation.
+class HintPopup(Hint):
+ hint_type = 'popup'
+
+ def __init__(self, name):
+ self.name = name
+
+ def instantiate(self, hint, prev_hints):
+ pass
@@ -3,16 +3,18 @@
def instantiate(self, hint, prev_hints):
pass
-# Hint sequence: each time this hint is sent, increase the message index until
-# the last message is reached, then repeat that.
+# Hint sequence: static type, but each time a hint is sent, increase the
+# message index until the last message is reached, then repeat that.
class HintSequence(Hint):
def __init__(self, name, length):